@@ -1,4 +1,6 @@
+import uritemplate  # pylint: disable=E0401
 from django.utils.encoding import smart_str
+from rest_framework.fields import Field
 from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.serializers import BaseSerializer, Serializer
 from rest_framework.utils import formatting
@@ -43,9 +45,27 @@ class PipelineSchemaMixin:
     deprecated: Container[HTTPMethod] = []
     security: Dict[HTTPMethod, List[Dict[str, List[str]]]] = {}
     external_docs: Dict[HTTPMethod, ExternalDocs] = {}
+    prefix: str = ""
 
     def get_operation(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
-        operation = super().get_operation(path, method)
+        operation = {}
+
+        operation["operationId"] = self.get_operation_id(path, method)
+        operation["description"] = self.get_description(path, method)
+
+        parameters: Dict[str, Dict[str, Any]] = self.get_path_parameters(path, method)
+        for name, params in self.get_filter_parameters(path, method).items():
+            parameters.setdefault(name, params)
+
+        operation["parameters"] = list(parameters.values())
+
+        request_body = self.get_request_body(path, method)
+        if request_body:
+            operation["requestBody"] = request_body
+
+        operation["responses"] = self.get_responses(path, method)
+        operation["tags"] = self.get_tags(path, method)
+
         if method in self.deprecated:
             operation["deprecated"] = True
 
@@ -96,6 +116,29 @@ class PipelineSchemaMixin:
 
         return components
 
+    def get_request_body(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
+        if method not in {"POST", "PUT", "PATCH", "DELETE"}:
+            return {}
+
+        serializer = self.get_request_serializer(path, method)
+
+        query_params = self.query_parameters.get(method, {})
+        path_params = uritemplate.variables(path)
+        params = list(query_params) + list(path_params)
+
+        if params:
+            new_serializer_class = type(
+                serializer.__class__.__name__,
+                (MockSerializer,),
+                {key: value for key, value in serializer.fields.items() if key not in params},
+            )
+            new_serializer_class.__doc__ = serializer.__class__.__doc__
+            serializer = new_serializer_class()
+
+        item_schema = self._get_reference(serializer)
+
+        return {"content": {"application/json": {"schema": item_schema}}}
+
     def get_responses(self, path: str, method: HTTPMethod) -> Dict[str, Any]:  # pylint: disable=W0613
         data = {}
 
@@ -115,6 +158,16 @@ class PipelineSchemaMixin:
 
             if info is ...:
                 serializer_class = self.view.get_serializer_class(output=True)
+
+                if getattr(serializer_class, "many", False):
+                    data.setdefault(
+                        "204",
+                        {
+                            "content": {"application/json": {"type": "string", "default": ""}},
+                            "description": "No Results",
+                        },
+                    )
+
                 info = serializer_class.__doc__ or ""
 
             serializer = self.view.initialize_serializer(serializer_class=serializer_class)
@@ -128,13 +181,50 @@ class PipelineSchemaMixin:
 
         return data
 
-    def get_filter_parameters(self, path, method):
-        parameters = super().get_filter_parameters(path, method)
-        if method not in ["GET", "PUT", "PATCH", "DELETE"]:
+    def get_tags(self, path: str, method: HTTPMethod) -> List[str]:  # pylint: disable=W0613
+        if self._tags:
+            return self._tags
+
+        if path.startswith("/"):
+            path = path[1:]
+
+        if path.startswith(self.prefix):
+            path = path[len(self.prefix) :]
+
+        return [path.split("/")[0].replace("_", "-")]
+
+    def get_path_parameters(self, path: str, method: HTTPMethod) -> Dict[str, Dict[str, Any]]:
+        parameters: Dict[str, Dict[str, Any]] = {}
+
+        serializer = self.get_request_serializer(path, method)
+        if getattr(serializer, "many", False):
+            serializer: Serializer = getattr(serializer, "child", serializer)
+
+        for variable in uritemplate.variables(path):
+            description = ""
+            schema = {"type": "string"}
+
+            field: Optional[Field] = serializer.fields.get(variable)
+            if field is not None:
+                description = str(field.help_text) if field.help_text is not None else ""
+                schema = self.map_field(field)
+
+            parameters[variable] = {
+                "name": variable,
+                "in": "path",
+                "required": True,
+                "description": description,
+                "schema": schema,
+            }
+
+        return parameters
+
+    def get_filter_parameters(self, path: str, method: HTTPMethod) -> Dict[str, Dict[str, Any]]:
+        parameters: Dict[str, Dict[str, Any]] = {}
+        if method not in {"GET", "PUT", "PATCH", "DELETE"}:
             return parameters
 
         serializer = self.get_request_serializer(path, method)
-
         if getattr(serializer, "many", False):
             serializer: Serializer = getattr(serializer, "child", serializer)
 
@@ -142,21 +232,22 @@ class PipelineSchemaMixin:
             if method != "GET" and field_name not in self.query_parameters.get(method, []):
                 continue
 
-            parameters += [
-                {
-                    "name": str(field_name),
-                    "required": field.required,
-                    "in": "query",
-                    "description": str(field.help_text) if field.help_text is not None else "",
-                    "schema": self.map_field(field),
-                },
-            ]
+            parameters[str(field_name)] = {
+                "name": str(field_name),
+                "required": field.required,
+                "in": "query",
+                "description": str(field.help_text) if field.help_text is not None else "",
+                "schema": self.map_field(field),
+            }
 
         return parameters
 
     def _get_reference(self, serializer: BaseSerializer) -> Dict[str, Any]:
         if isinstance(serializer, MockSerializer):
-            response_schema = convert_to_schema(serializer._example)  # pylint: disable=W0212
+            if serializer.fields:
+                response_schema = self.map_serializer(serializer)
+            else:
+                response_schema = convert_to_schema(serializer._example)  # pylint: disable=W0212
 
         elif getattr(serializer, "many", False):
             response_schema = {
@@ -165,9 +256,6 @@ class PipelineSchemaMixin:
                     "$ref": f"#/components/schemas/{self.get_component_name(getattr(serializer, 'child', serializer))}"
                 },
             }
-            paginator = self.get_paginator()
-            if paginator:  # pragma: no cover
-                response_schema = paginator.get_paginated_response_schema(response_schema)
         else:
             response_schema = {
                 "$ref": f"#/components/schemas/{self.get_component_name(serializer)}",
@@ -190,13 +278,15 @@ class PipelineSchema(PipelineSchemaMixin, AutoSchema):
         deprecated: Optional[Container[HTTPMethod]] = None,
         security: Optional[Dict[HTTPMethod, List[Dict[str, List[str]]]]] = None,
         external_docs: Optional[Dict[HTTPMethod, ExternalDocs]] = None,
+        prefix: Optional[str] = None,
         tags: Optional[Sequence[str]] = None,
         operation_id_base: Optional[str] = None,
         component_name: Optional[str] = None,
     ):
-        self.responses = responses or {}
-        self.query_parameters = query_parameters or {}
-        self.deprecated = deprecated or []
-        self.security = security or {}
-        self.external_docs = external_docs or {}
+        self.responses = responses or self.responses
+        self.query_parameters = query_parameters or self.query_parameters
+        self.deprecated = deprecated or self.deprecated
+        self.security = security or self.security
+        self.external_docs = external_docs or self.external_docs
+        self.prefix = prefix or self.prefix
         super().__init__(tags=tags, operation_id_base=operation_id_base, component_name=component_name)
